package com.hncy.sjdz.constant.enums;

import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.Objects;

/**
 * ClassifyTypeEnum 事件分类
 * <p>
 * Enum("name","value")
 * <p>
 * ----------------------------------
 * <p>
 * BROAD_CATEGORY("大类", "1")
 * <p>
 * SUBCLASS("小类", "2")
 * <p>
 * SUBDIVISION("细类", "3")
 * <p>
 * REGISTER_COND("立案条件", "4")
 *
 * @Author: lm
 * @Date: 2023/11/30
 */
@Getter
@RequiredArgsConstructor
public enum ClassifyTypeEnum {

    /**
     * 分类(事部件) v:"0"
     */
    CATEGORY("分类(事部件)", "0"),
    /**
     * 大类 v:"1"
     */
    BROAD_CATEGORY("大类", "1"),
    /**
     * 小类 v:"2"
     */
    SUBCLASS("小类", "2"),
    /**
     * 细类 v:"3"
     */
    SUBDIVISION("细类", "3"),
    /**
     * 立案条件 v:"4"
     */
    REGISTER_COND("立案条件", "4");

    private final String name;

    @JsonValue
    private final String value;

    public static String getName(String value) {
        ClassifyTypeEnum[] enums = ClassifyTypeEnum.values();
        for (ClassifyTypeEnum nowEnum : enums) {
            if (nowEnum.getValue().equals(value)) {
                return nowEnum.getName();
            }
        }
        return "/";
    }

    public static String convertName(ClassifyTypeEnum enumObj) {
        return Objects.isNull(enumObj) ? "/" : enumObj.getName();
    }

}