package com.hncy.sjdz.constant.enums;

import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.Objects;

/**
 * 体征指数 指标类型
 * <p>
 * Enum("name","value")
 * <p>
 * ----------------------------------
 * <p>
 * INSIDE("内评价", "0")
 * <p>
 * OUTSIDE("外评价", "1")
 * <p>
 * QUESTION("问题指标", "Q")
 * <p>
 * OBJECTIVE("目标指标", "O")
 *
 * @Author: lm
 * @Date: 2024/3/27
 */
@Getter
@RequiredArgsConstructor
public enum IndexIndicatorTypeEnum {

    /**
     * 内评价 v:"0"
     */
    INSIDE("内评价", "0"),
    /**
     * 外评价 v:"1"
     */
    OUTSIDE("外评价", "1"),
    /**
     * 问题指标 v:"Q"
     */
    QUESTION("问题指标", "Q"),
    /**
     * 目标指标 v:"O"
     */
    OBJECTIVE("目标指标", "O"),;

    private final String name;

    @JsonValue
    private final String value;

    public static String getName(String value) {
        IndexIndicatorTypeEnum[] enums = IndexIndicatorTypeEnum.values();
        for (IndexIndicatorTypeEnum nowEnum : enums) {
            if (nowEnum.getValue().equals(value)) {
                return nowEnum.getName();
            }
        }
        return "/";
    }

    public static String convertName(IndexIndicatorTypeEnum enumObj) {
        return Objects.isNull(enumObj) ? "/" : enumObj.getName();
    }

}