package com.hncy.sjdz.constant.enums;

import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.Objects;

/**
 * ResponsibilitySystemLevelEnum 责任级别
 * <p>
 * Enum("name","value")
 * <p>
 * ----------------------------------------
 * <p>
 * CITY("市级", "1")
 * <p>
 * DISTRICTS_CITIES_COUNTIES("区市县级", "2")
 * <p>
 * SUBDISTRICT_OFFICE("街道办级", "3")
 * <p>
 * COMMUNITY("社区级", "4")
 * <p>
 * COMPANY("公司级", "5")
 *
 * @Author: lm
 * @Date: 2023/11/30
 */
@Getter
@RequiredArgsConstructor
public enum ResponsibilitySystemLevelEnum {

    /**
     * 市级 v:"1"
     */
    CITY("市级", "1"),
    /**
     * 区市县级 v:"2"
     */
    DISTRICTS_CITIES_COUNTIES("区市县级", "2"),
    /**
     * 街道办级 v:"3"
     */
    SUBDISTRICT_OFFICE("街道办级", "3"),
    /**
     * 社区级 v:"4"
     */
    COMMUNITY("社区级", "4"),
    /**
     * 公司级 v:"5
     */
    COMPANY("公司级", "5");

    private final String name;

    @JsonValue
    private final String value;

    public static String getName(String value) {
        ResponsibilitySystemLevelEnum[] enums = ResponsibilitySystemLevelEnum.values();
        for (ResponsibilitySystemLevelEnum nowEnum : enums) {
            if (nowEnum.getValue().equals(value)) {
                return nowEnum.getName();
            }
        }
        return "/";
    }

    public static String convertName(ResponsibilitySystemLevelEnum enumObj) {
        return Objects.isNull(enumObj) ? "/" : enumObj.getName();
    }

}