package com.hncy.sjdz.base.models.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 诚管24--事件附件表
 * </p>
 *
 * @author liyl
 * @since 2023/12/11 17:31
 */
@Schema(description = "诚管24--事件附件表")
@Data
public class EventAttachmentInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @NotBlank(message = "[主键]不能为空")
    @Size(max = 64, message = "编码长度不能超过64")
    @Schema(description = "主键")
    @Length(max = 64, message = "编码长度不能超过64")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private String id;

    /**
     * 事件ID
     */
    @Size(max = 64, message = "事件ID长度不能超过64")
    @Schema(description = "事件ID")
    @Length(max = 64, message = "事件ID长度不能超过64")
    private String mId;

    /**
     * 附件路径
     */
    @Size(max = 600, message = "附件路径长度不能超过600")
    @Schema(description = "附件路径")
    @Length(max = 600, message = "附件路径长度不能超过600")
    private String path;

    /**
     * 附件文件类型
     */
    @Size(max = 64, message = "附件文件类型长度不能超过64")
    @Schema(description = "附件文件类型")
    @Length(max = 64, message = "附件文件类型长度不能超过64")
    private String fileType;

    /**
     * 案件附件（1.处置前、2处置后、3结案...）
     */
    @Size(max = 4, message = "案件附件长度不能超过2")
    @Schema(description = "案件附件（1.处置前、2处置后、3结案...）")
    @Length(max = 4, message = "案件附件长度不能超过2")
    private String annexType;

    /**
     * 删除标志
     */
    @Size(max = 2, message = "删除标志长度不能超过2")
    @Schema(description = "删除标志")
    @Length(max = 2, message = "删除标志长度不能超过2")
    private String delFlag;

    /**
     * 创建者id
     */
    @Size(max = 64, message = "创建者id长度不能超过64")
    @Schema(description = "创建者id")
    @Length(max = 64, message = "创建者id长度不能超过64")
    private String createById;

    /**
     * 创建者
     */
    @Size(max = 64, message = "创建者长度不能超过64")
    @Schema(description = "创建者")
    @Length(max = 64, message = "创建者长度不能超过64")
    private String createByName;

    /**
     * 创建日期
     */
    @Schema(description = "创建日期")
    private LocalDateTime createTime;

    /**
     * 更新者id
     */
    @Size(max = 64, message = "更新者id长度不能超过64")
    @Schema(description = "更新者id")
    @Length(max = 64, message = "更新者id长度不能超过64")
    private String updateById;

    /**
     * 更新者
     */
    @Size(max = 64, message = "更新者长度不能超过64")
    @Schema(description = "更新者")
    @Length(max = 64, message = "更新者长度不能超过64")
    private String updateByName;

    /**
     * 更新日期
     */
    @Schema(description = "更新日期")
    private LocalDateTime updateTime;

    /**
     * 上传附件时对应的流转记录id
     */
    @Schema(description = "上传附件时对应的流转记录id")
    @Size(max = 64, message = "对应的流转记录id长度不能超过64")
    @Length(max = 64, message = "对应的流转记录id长度不能超过64")
    private String cirId;

}
