package com.hncy.sjdz.base.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.sjdz.base.models.dto.BaseLabelEntity;
import com.hncy.sjdz.base.models.entity.Component;
import com.hncy.sjdz.base.models.entity.CzzyResourceInfo;
import com.hncy.sjdz.base.models.entity.ResponsibilityGridDivision;
import com.hncy.sjdz.base.models.vo.ComponentTypeStatisticsVO;
import com.hncy.sjdz.base.service.ComponentService;
import com.hncy.sjdz.base.mapper.ComponentMapper;
import com.hncy.sjdz.base.service.CzzyResourceInfoService;
import com.hncy.sjdz.base.service.ResponsibilityGridDivisionService;
import com.hncy.sjdz.constant.enums.DisposalResourcesTypeEnum;
import com.hncy.sjdz.util.SelectOption;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.security.service.HncyUser;
import com.hncy4cloud.hncy.common.security.util.SecurityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
* @author tyz
* @description 针对表【component(部件表)】的数据库操作Service实现
* @createDate 2024-11-13 10:05:58
*/
@Service
public class ComponentServiceImpl extends ServiceImpl<ComponentMapper, Component>
    implements ComponentService{

	@Resource
	private ResponsibilityGridDivisionService responsibilityGridDivisionService;
	@Resource
	private CzzyResourceInfoService czzyResourceInfoService;
    @Override
    public R getGridResources() {
		//获取城市部件数量
		//获取我的网格代码
		HncyUser user = SecurityUtils.getUser();
		List<String> gridCodes = responsibilityGridDivisionService.getMyGridCodes(user.getId());
		Integer cityComponentCount = baseMapper.getCityComponentCount(gridCodes);
		//处置资源数量
		Integer resourcesCount = czzyResourceInfoService.getResourcesCount(gridCodes, null);
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("cityComponentCount", cityComponentCount);
		jsonObject.put("resourcesCount", resourcesCount);
		return R.ok(jsonObject);
    }

	@Override
	public ComponentTypeStatisticsVO getComponentTypeStatistics() {
		//获取我的网格代码
		HncyUser user = SecurityUtils.getUser();
		List<String> gridCodes = responsibilityGridDivisionService.getMyGridCodes(user.getId());
		ComponentTypeStatisticsVO componentTypeStatisticsVO = baseMapper.selectComponentTypeStatistics(gridCodes);
		return componentTypeStatisticsVO;
	}

	@Override
	public List<BaseLabelEntity> getComponentClassStatistics() {
		HncyUser user = SecurityUtils.getUser();
		List<String> gridCodes = responsibilityGridDivisionService.getMyGridCodes(user.getId());
		List<BaseLabelEntity> bigCodeStatistics = baseMapper.getBigCodeStatistics(gridCodes);
		bigCodeStatistics.forEach(item->{
			List<BaseLabelEntity> smallStatistics = baseMapper.getSmallStatistics(item.getValue(), gridCodes);
			item.setChildren(smallStatistics);
		});
		return bigCodeStatistics;
	}

	@Override
	public List<BaseLabelEntity> getResourcesCount() {
		HncyUser user = SecurityUtils.getUser();
		List<String> gridCodes = responsibilityGridDivisionService.getMyGridCodes(user.getId());
		List<BaseLabelEntity> resources = new ArrayList<>();
		for (DisposalResourcesTypeEnum disposalResourcesTypeEnum: DisposalResourcesTypeEnum.values()){
			Integer resourcesCount = czzyResourceInfoService.getResourcesCount(gridCodes, disposalResourcesTypeEnum.getCode());
			BaseLabelEntity baseLabelEntity = new BaseLabelEntity();
			baseLabelEntity.setValue(disposalResourcesTypeEnum.getCode());
			baseLabelEntity.setLabel(disposalResourcesTypeEnum.getName());
			baseLabelEntity.setCount(resourcesCount);
			resources.add(baseLabelEntity);
		}
		return resources;
	}
}




