package com.hncy.sjdz.base.service.impl;


import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.sjdz.base.mapper.SafetyDictionaryMapper;
import com.hncy.sjdz.base.mapper.SafetyMonitoringObjectInfoMapper;
import com.hncy.sjdz.base.mapper.SafetyMonitoringRecordInfoMapper;
import com.hncy.sjdz.base.models.entity.SafetyDictionary;
import com.hncy.sjdz.base.models.entity.SafetyMonitoringObjectInfo;
import com.hncy.sjdz.base.models.entity.SafetyMonitoringRecordInfo;
import com.hncy.sjdz.base.service.SafetyMonitoringObjectInfoService;
import com.hncy.sjdz.base.util.cdEncryption.DataEncryptionUtil;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.mybatis.custom.CustomPage;
import com.hncy4cloud.hncy.common.mybatis.custom.HncyPageHelper;
import io.swagger.v3.core.util.Json;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author cp
 * @since 2024-11-07 15:23:28
 */
@Service
@Slf4j
public class SafetyMonitoringObjectInfoServiceImpl extends ServiceImpl<SafetyMonitoringObjectInfoMapper, SafetyMonitoringObjectInfo> implements SafetyMonitoringObjectInfoService {

	@Autowired
	private SafetyMonitoringObjectInfoMapper safetyMonitoringObjectInfoMapper;
	@Autowired
	private SafetyMonitoringRecordInfoMapper safetyMonitoringRecordInfoMapper;

	@Autowired
	private SafetyDictionaryMapper safetyDictionaryMapper;


	@Autowired(required = false)
	private DataEncryptionUtil dataEncryptionUtil;

	@Override
	public R statisticalRiskLevel(String parentTypeCode, String areaCode) {
		return R.ok(safetyMonitoringObjectInfoMapper.statisticalRiskLevel(parentTypeCode, areaCode));
	}

	@Value(value = "${picture.objectUrl}")
	private String pictureUrl;

	@Value(value = "${picture.objectZwwUrl}")
	private String pictureZwwUrl;

	@Override
	public R findListForMap(String parentTypeCode, String monitoringObjectTypeCodeList, String lat, String lon, String distance, String areaCode) {
		String[] split = null;
		if (monitoringObjectTypeCodeList != null && !monitoringObjectTypeCodeList.equals("")) {
			split = monitoringObjectTypeCodeList.split(",");
		}
//
//
//		List typeCodeList = new ArrayList<>();
//		typeCodeList.add(parentTypeCode);
//		List<SafetyDictionary> safetyDictionaryList = safetyDictionaryMapper.selectList(Wrappers.<SafetyDictionary>lambdaQuery().eq(SafetyDictionary::getParentCode, parentTypeCode));
//		if (safetyDictionaryList.size() > 0) {
//			List<String> ids = safetyDictionaryList.stream().map(SafetyDictionary::getTypeCode).collect(Collectors.toList());
//			typeCodeList.addAll(ids);
////			List<SafetyDictionary> threeList = SafetyDictionaryMapper.selectList(Wrappers.<SafetyDictionary>lambdaQuery().in(SafetyDictionary::getParentCode, ids));
////			if (threeList.size() > 0) {
////				List<String> threeIds = threeList.stream().map(SafetyDictionary::getTypeCode).collect(Collectors.toList());
////				typeCodeList.addAll(threeIds);
////			}
//		}
//

		List<Map> listForMap = safetyMonitoringObjectInfoMapper.findListForMap(parentTypeCode, split, lat, lon, distance, areaCode);


		CustomPage pageItem = HncyPageHelper.startManualPage(listForMap);
		List<Map> items = pageItem.getItems();
		for (Map map : items) {
			if (map.get("encryption_status").equals("1")) {
				if (map.get("monitoringObjectName") != null) {
					String monitoringObjectName = dataEncryptionUtil.decryptSM4(map.get("monitoringObjectName").toString());
					map.put("monitoringObjectName", monitoringObjectName);

				}

				if (map.get("x_pos") != null) {
					String x_pos = dataEncryptionUtil.decryptSM4(map.get("x_pos").toString());
					map.put("x_pos", x_pos);
				}

				if (map.get("y_pos") != null) {
					String y_pos = dataEncryptionUtil.decryptSM4(map.get("y_pos").toString());
					map.put("y_pos", y_pos);
				}

				if (map.get("monitoringObjectTypeName") != null) {
					String monitoring_object_type_name = dataEncryptionUtil.decryptSM4(map.get("monitoringObjectTypeName").toString());
					map.put("monitoringObjectTypeName", monitoring_object_type_name);
				}
			}
		}
		return R.ok(pageItem);
	}


	@Override
	public R getInfo(String id) {
		Map map = safetyMonitoringObjectInfoMapper.getInfo(id);
		if (map.get("encryption_status").equals("1")) {
			if (map.get("photos") != null) {
				String photos = dataEncryptionUtil.decryptSM4(map.get("photos").toString());
				String photo = pictureUrl + photos;
				map.put("photos", photo);

				String photoZWW = pictureZwwUrl+photos;
				map.put("photosZWW",photoZWW);
			}

			String monitoring_object_name = dataEncryptionUtil.decryptSM4(map.get("monitoring_object_name").toString());
			map.put("monitoring_object_name", monitoring_object_name);

			String x_pos = dataEncryptionUtil.decryptSM4(map.get("x_pos").toString());
			map.put("x_pos", x_pos);

			String y_pos = dataEncryptionUtil.decryptSM4(map.get("y_pos").toString());
			map.put("y_pos", y_pos);


			String monitoring_object_type_name = dataEncryptionUtil.decryptSM4(map.get("monitoring_object_type_name").toString());
			map.put("monitoring_object_type_name", monitoring_object_type_name);


			String position = dataEncryptionUtil.decryptSM4(map.get("position").toString());
			map.put("position", position);


			List<SafetyMonitoringRecordInfo> list = safetyMonitoringRecordInfoMapper.selectList(Wrappers.<SafetyMonitoringRecordInfo>lambdaQuery()
					.eq(SafetyMonitoringRecordInfo::getMonitoringObjectId, id)
					.groupBy(SafetyMonitoringRecordInfo::getMonitoringProject));

			List projectList = new ArrayList<>();
			for (SafetyMonitoringRecordInfo safetyMonitoringRecordInfo : list) {

				Map recordMap = new HashMap<>();
				List<Map> projectInfo = safetyMonitoringObjectInfoMapper.selectByMonitoringProject(id, safetyMonitoringRecordInfo.getMonitoringProject());
				for (Map projectInfoMap : projectInfo) {
					if (projectInfoMap.get("encryption_status").equals("1")) {
						String monitoringValue = dataEncryptionUtil.decryptSM4(projectInfoMap.get("monitoringValue").toString());
						projectInfoMap.put("monitoringValue", monitoringValue);
					}
				}
				if (safetyMonitoringRecordInfo.getEncryptionStatus().equals("1")) {
					String monitoringProject = dataEncryptionUtil.decryptSM4(safetyMonitoringRecordInfo.getMonitoringProject());
					recordMap.put("projectName", monitoringProject);
				} else {
					recordMap.put("projectName", safetyMonitoringRecordInfo.getMonitoringProject());
				}


				recordMap.put("reportObjectList", projectInfo);
				projectList.add(recordMap);
			}
			map.put("projectList", projectList);
			return R.ok(map);


		} else {
			String photo = pictureUrl + map.get("photos");
			map.put("photos", photo);
			String photoZWW = pictureZwwUrl+map.get("photos");
			map.put("photosZWW",photoZWW);
			List<SafetyMonitoringRecordInfo> list = safetyMonitoringRecordInfoMapper.selectList(Wrappers.<SafetyMonitoringRecordInfo>lambdaQuery()
					.eq(SafetyMonitoringRecordInfo::getMonitoringObjectId, id)
					.groupBy(SafetyMonitoringRecordInfo::getMonitoringProject));
			List projectList = new ArrayList<>();
			for (SafetyMonitoringRecordInfo safetyMonitoringRecordInfo : list) {
				Map recordMap = new HashMap<>();
				List<Map> projectInfo = safetyMonitoringObjectInfoMapper.selectByMonitoringProject(id, safetyMonitoringRecordInfo.getMonitoringProject());
				for (Map projectInfoMap : projectInfo) {
					projectInfoMap.get("monitoringValue");
				}
				recordMap.put("projectName", safetyMonitoringRecordInfo.getMonitoringProject());
				recordMap.put("reportObjectList", projectInfo);
				projectList.add(recordMap);
			}
			map.put("projectList", projectList);
			return R.ok(map);


		}

	}


	@Override
	public R statisticalType() {
		List<Map> list = safetyMonitoringObjectInfoMapper.statisticalType();

		return R.ok(list);
	}
}