package com.hncy.sjdz.base.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.util.StringUtil;
import com.hncy.sjdz.base.models.entity.SjdzInterfaceInfo;
import com.hncy.sjdz.base.mapper.SjdzInterfaceInfoMapper;
import com.hncy.sjdz.base.models.vo.*;
import com.hncy.sjdz.base.service.SjdzInterfaceInfoService;
import com.hncy.sjdz.base.util.UrlUtils;
import com.hncy.sjdz.util.JsonUtils;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.core.util.RedisUtils;
import com.troy.keeper.utils.SM4Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.CompletableFuture;


/**
 * 智慧城管数据底座接口
 *
 * @author zhaoting
 * @date 2024-12-03 10:53:33
 */
@Service
@Slf4j
public class SjdzInterfaceInfoServiceImpl extends ServiceImpl<SjdzInterfaceInfoMapper, SjdzInterfaceInfo> implements SjdzInterfaceInfoService {

	@Override
	public R getSjdzInfoData(InterfaceVO interfaceVO) {
		String typeCode = interfaceVO.getTypeCode();
		if(StringUtil.isEmpty(typeCode)){
			return R.failed("接口类型不能为空");
		}else {
			List<SjdzInterfaceInfo> sjdzInterfaceInfos = baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery().eq(SjdzInterfaceInfo::getTypeCode, typeCode));
			if(sjdzInterfaceInfos.size()==0){
				return R.failed("未查询到该类型接口信息");
			}
			SjdzInterfaceInfo sjdzInterfaceInfo = sjdzInterfaceInfos.get(0);
			String isCache = sjdzInterfaceInfo.getIsCache();
			int i = interfaceVO.hashCode();
			String sjdzRedis="sjdz_"+typeCode+":" + i;
			//需要缓存
			if("1".equals(isCache)){
				Object o = RedisUtils.get(sjdzRedis);
				if(o!=null){
					long expire = RedisUtils.getExpire(sjdzRedis);
					if(expire<60*60*1){
						//异步调取
						CompletableFuture<String> future = CompletableFuture.supplyAsync(() -> {
							try {
								this.RedisData(i, interfaceVO, sjdzInterfaceInfo);
							} catch (Exception e) {
								e.printStackTrace();
							}
							return null;
						});
						future.thenAccept(result -> {log.info("异步调取缓存成功");});
					}
					return R.ok(o);
				}
			}
			String interfaceAddress = sjdzInterfaceInfo.getInterfaceAddress();
			String method = sjdzInterfaceInfo.getMethod();
			String authUserName = sjdzInterfaceInfo.getAuthUserName();
			String authUserKey = sjdzInterfaceInfo.getAuthUserKey();
			String id = interfaceVO.getId();
			String url= interfaceAddress;
			if(StringUtil.isNotEmpty(id)){
				url=url+"/"+id;
			}
			Map<String, Object> params = interfaceVO.getParams();
			if(StringUtil.isNotEmpty(authUserName)){
				params.put("authUserName",authUserName);
			}
			if(StringUtil.isNotEmpty(authUserKey)){
				params.put("authUserKey",authUserKey);
			}
			if(params!=null){
				String s = UrlUtils.mapToUrlParams(params);
				url+="?"+s;
			}
			log.info("url:{}",url);
			HttpRequest request = HttpUtil.createRequest(cn.hutool.http.Method.valueOf(method), url);

			request.header("Content-Type","application/json");
			Map<String, Object> data = interfaceVO.getData();
			if(data!=null){
				String s = JsonUtils.toJson(data);
				request.body(s);
			}

			String result  = request.execute().body();
			log.info("result:{}",result);
			String isDecryption = sjdzInterfaceInfo.getIsDecryption();
			if("1".equals(isDecryption)){
				String privateKey = sjdzInterfaceInfo.getPrivateKey();
				try {
					result = SM4Util.decryptEcb(privateKey,result);
					JSONObject entries = JSONUtil.parseObj(result,false);
					if("1".equals(isCache)){
						RedisUtils.set(sjdzRedis, entries,60*60*1);
					}
					return R.ok(entries);
				} catch (Exception e) {
					e.printStackTrace();
					log.error("{}出现问题:{}--{}",sjdzInterfaceInfo.getName(),e.getMessage(),result);
					return R.failed("获取数据失败");
				}
			}else {
				//不需要解密
				JSONObject entries = JSONUtil.parseObj(result,false);
				if("1".equals(isCache)){
					RedisUtils.set(sjdzRedis, entries,60*60*6);
				}
				return R.ok(entries);
			}
		}
	}

	private void RedisData(	int i ,InterfaceVO interfaceVO,SjdzInterfaceInfo sjdzInterfaceInfo){
		String interfaceAddress = sjdzInterfaceInfo.getInterfaceAddress();
		String method = sjdzInterfaceInfo.getMethod();
		String authUserName = sjdzInterfaceInfo.getAuthUserName();
		String authUserKey = sjdzInterfaceInfo.getAuthUserKey();
		String id = interfaceVO.getId();
		String url= interfaceAddress;
		if(StringUtil.isNotEmpty(id)){
			url=url+"/"+id;
		}
		Map<String, Object> params = interfaceVO.getParams();
		if(StringUtil.isNotEmpty(authUserName)){
			params.put("authUserName",authUserName);
		}
		if(StringUtil.isNotEmpty(authUserKey)){
			params.put("authUserKey",authUserKey);
		}
		if(params!=null){
			String s = UrlUtils.mapToUrlParams(params);
			url+="?"+s;
		}
		log.info("url:{}",url);
		HttpRequest request = HttpUtil.createRequest(cn.hutool.http.Method.valueOf(method), url);

		request.header("Content-Type","application/json");
		Map<String, Object> data = interfaceVO.getData();
		if(data!=null){
			String s = JsonUtils.toJson(data);
			request.body(s);
		}

		String result  = request.execute().body();
		log.info("result:{}",result);
		String isDecryption = sjdzInterfaceInfo.getIsDecryption();
		if("1".equals(isDecryption)){
			String privateKey = sjdzInterfaceInfo.getPrivateKey();
			try {
				result = SM4Util.decryptEcb(privateKey,result);
				JSONObject entries = JSONUtil.parseObj(result,false);
				RedisUtils.set("sjdz:" + i, entries,60*60*6);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}else {
			//不需要解密
			JSONObject entries = JSONUtil.parseObj(result,false);
			RedisUtils.set("sjdz:" + i, entries,60*60*6);
		}
	}
	@Override
	public R getSqLx(InterfaceVO interfaceVO) {
		Map<String, Object> params = interfaceVO.getParams();
		interfaceVO.setParams(params);
		R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
		if(sjdzInfoData.isSuccess()) {
			Map data = (Map) sjdzInfoData.getData();
			Map data1 = (Map)data.get("data");
			Object records1 = data1.get("records");
			JSONArray jsonArray = JSONUtil.parseArray(records1);
			List<SqxzData> records = jsonArray.toList(SqxzData.class);
			List<SqxzData> recordNews=new ArrayList<>();
			for(SqxzData sqxzData:records){
				String xl = sqxzData.getXl();
				if (!"其他".equals(xl)) {
					recordNews.add(sqxzData);
				}
			}
			data1.put("records",recordNews);
			data.put("data",data1);
			sjdzInfoData.setData(data);
			return sjdzInfoData;
		}
		return R.ok();
	}
	@Override
	public R getMzhsData(InterfaceVO interfaceVO) {
		Map map = new HashMap();
		List<String> mzhsCodesDates =new ArrayList<>();
		mzhsCodesDates.add("zzcc-quajNum");
		mzhsCodesDates.add("zzcc-cqajNum");
		mzhsCodesDates.add("zzcc-12345blz");
		List<SjdzInterfaceInfo> sjdzInterfaceInfos =
				baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery()
				.in(SjdzInterfaceInfo::getTypeCode, mzhsCodesDates));
		log.info("sjdzInterfaceInfos:{}",sjdzInterfaceInfos);
		Map<String, Object> params = interfaceVO.getParams();
		interfaceVO.setParams(params);
		for(SjdzInterfaceInfo sjdzInterfaceInfo : sjdzInterfaceInfos){
			interfaceVO.setTypeCode(sjdzInterfaceInfo.getTypeCode());
			R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
			if(sjdzInfoData.isSuccess()) {
				Map data = (Map) sjdzInfoData.getData();
				Map data1 = (Map)data.get("data");
				Object records1 = data1.get("records");
				JSONArray jsonArray = JSONUtil.parseArray(records1);
				List<RecordQZData> records = jsonArray.toList(RecordQZData.class);
				log.info("records:{}"+sjdzInterfaceInfo.getTypeCode(),records);
				if("zzcc-quajNum".equals(sjdzInterfaceInfo.getTypeCode())) {
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("slNum",sum);
					}else {
						map.put("slNum",0);
					}
				}else if("zzcc-cqajNum".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("cqNum",sum);
					}else {
						map.put("cqNum",0);
					}

				}else if("zzcc-12345blz".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("blNum",sum);
					}else {
						map.put("blNum",0);
					}
				}
			}
		}
		LocalDate currentDate = LocalDate.now();
		DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
		String time = currentDate.format(formatter);
		params.put("startTime",time);
		params.put("endTime",time);
		interfaceVO.setParams(params);
		//今日
		for(SjdzInterfaceInfo sjdzInterfaceInfo : sjdzInterfaceInfos){
			interfaceVO.setTypeCode(sjdzInterfaceInfo.getTypeCode());
			R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
			if(sjdzInfoData.isSuccess()) {
				Map data = (Map) sjdzInfoData.getData();
				Map data1 = (Map)data.get("data");
				Object records1 = data1.get("records");
				JSONArray jsonArray = JSONUtil.parseArray(records1);
				List<RecordQZData> records = jsonArray.toList(RecordQZData.class);
				log.info("records:{}"+sjdzInterfaceInfo.getTypeCode(),records);
				if("zzcc-quajNum".equals(sjdzInterfaceInfo.getTypeCode())) {
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("slNumDay",sum);
					}else {
						map.put("slNumDay",0);
					}
				}else if("zzcc-cqajNum".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("cqNumDay",sum);
					}else {
						map.put("cqNumDay",0);
					}

				}else if("zzcc-12345blz".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("blNumDay",sum);
					}else {
						map.put("blNumDay",0);
					}
				}
			}
		}
		return R.ok(map);
	}

	@Override
	public R getCallInformationInfoById(String id) {
		InterfaceVO interfaceVO = new InterfaceVO();
		interfaceVO.setTypeCode("new-12345-tsgdlb");
		Map<String,Object> datadd=new HashMap<>();
		datadd.put("sczj",id);
		interfaceVO.setParams(datadd);
		R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
		if(sjdzInfoData.isSuccess()){
			Map data = (Map) sjdzInfoData.getData();
			Map data1 = (Map)data.get("data");
			Object records1 = data1.get("records");
			JSONArray jsonArray = JSONUtil.parseArray(records1);
			List<Map> records = jsonArray.toList(Map.class);
			if(records!=null && records.size()>0){
				Map map1 = records.get(0);
				Object list = map1.get("list");
				JSONArray jsonArrayNew = JSONUtil.parseArray(list);
				List<Map> listMap = jsonArrayNew.toList(Map.class);
				Map map=listMap.get(0);
				CallInformationVO callInformationVO = new CallInformationVO();
				callInformationVO.setOtherInfo(map);
				Object sczj = map.get("sczj");
				if(sczj!=null){
					callInformationVO.setId(sczj.toString());
				}
				Object bt = map.get("bt");
				if(bt!=null){
					callInformationVO.setTitle(bt.toString());
				}
				Object ldlx = map.get("ldlx");
				if(ldlx!=null){
					callInformationVO.setCallType(ldlx.toString());
				}
				Object lxrmc = map.get("lxrmc");
				if(lxrmc!=null){
					callInformationVO.setSenderName(lxrmc.toString());
				}
				Object ly = map.get("ly");
				if(ly!=null){
					callInformationVO.setSource(ly.toString());
				}else {
					Object lx = map.get("lx");
					callInformationVO.setSource(lx.toString());
				}
				Object ldxnr = map.get("ldxnr");
				if(ldxnr!=null){
					callInformationVO.setCallContent(ldxnr.toString());
				}
				Object bldw = map.get("bldw");
				if(bldw!=null){
					if("-1".equals(bldw.toString())){
						callInformationVO.setHandlingUnit("");
					}else {
						callInformationVO.setHandlingUnit(bldw.toString());
					}
				}
				Object blzt = map.get("blzt");
				if(blzt!=null){
					callInformationVO.setHandlingStatus(blzt.toString());
				}
				Object ssqy = map.get("ssqy");
				if(ssqy!=null){
					callInformationVO.setArea(ssqy.toString());
				}
				Object ldxsj = map.get("ldxsj");
				if(ldxsj!=null){
					callInformationVO.setReportTime(ldxsj.toString());
				}
				if(map.get("hfsj")!=null){
					callInformationVO.setProcessingTime(map.get("hfsj").toString());
				}
				if(map.get("hfnr")!=null){
					callInformationVO.setProcessingContent(map.get("hfnr").toString());
				}
				return R.ok(callInformationVO);
			}else {
				return R.failed("获取数据失败");
			}
		}else {
			return R.failed("获取数据失败");
		}
	}

	@Override
	public R getQzGfData(InterfaceVO interfaceVO) {
		R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
		if(sjdzInfoData.isSuccess()){
			Map data = (Map) sjdzInfoData.getData();
			Map data1 = (Map)data.get("data");
			Object records1 = data1.get("records");
			JSONArray jsonArray = JSONUtil.parseArray(records1);
			List<Map> records = jsonArray.toList(Map.class);
			if(records!=null && records.size()>0){
				List<QzTimeDataAllVO> qzTimeDataAllVOS=new ArrayList<>();
				for(Map map : records){
					QzTimeDataAllVO qzTimeDataAllVO = new QzTimeDataAllVO();
					String dl = map.get("dl").toString();
					BigDecimal num = (BigDecimal) map.get("num");
					Object ListString = map.get("list");
					JSONArray numArray = JSONUtil.parseArray(ListString);
					List<QzTimeDataVO> qzTimeDataVOS = numArray.toList(QzTimeDataVO.class);
					List<QzTimeDataVO> qzTimeDataNewVOS=new ArrayList<>();
					for(int i=0;i<24;i++){
						QzTimeDataVO qzTimeDataVO=new QzTimeDataVO();
						qzTimeDataVO.setTimes(i);
						int finalI = i;
						Optional<QzTimeDataVO> first = qzTimeDataVOS.stream().filter(item -> finalI ==item.getTimes()).findFirst();
						if(first.isPresent()){
							qzTimeDataVO.setNum(first.get().getNum());
						}else {
							qzTimeDataVO.setNum(BigDecimal.ZERO);
						}
						qzTimeDataNewVOS.add(qzTimeDataVO);
					}
					qzTimeDataAllVO.setNum(num);
					qzTimeDataAllVO.setName(dl);
					qzTimeDataAllVO.setData(qzTimeDataNewVOS);
					qzTimeDataAllVOS.add(qzTimeDataAllVO);
				}
				List<QzTimeDataVO> qzTimeDataVOS=new ArrayList<>();
				for(int i=0;i<24;i++){
					QzTimeDataVO qzTimeDataAllTotalVO=new QzTimeDataVO();
					qzTimeDataAllTotalVO.setTimes(i);
					int aa=0;
					for(QzTimeDataAllVO qzTimeDataAllVO:qzTimeDataAllVOS){
						List<QzTimeDataVO> data2 = qzTimeDataAllVO.getData();
						QzTimeDataVO qzTimeDataVO = data2.get(i);
						aa+=qzTimeDataVO.getNum().intValue();
					}
					qzTimeDataAllTotalVO.setNum(BigDecimal.valueOf(aa));
					qzTimeDataVOS.add(qzTimeDataAllTotalVO);
				}
				QzTimeDataAllVO qzTimeDataAllTotalVO=new QzTimeDataAllVO();
				qzTimeDataAllTotalVO.setName("整体");
				qzTimeDataAllTotalVO.setData(qzTimeDataVOS);
				Map map=new HashMap();
				map.put("data",qzTimeDataAllVOS);
				map.put("all",qzTimeDataAllTotalVO);
				return R.ok(map);
			}else {
				return R.ok();
			}
		}else {
			return R.failed();
		}

	}

	@Override
	public Object getGzInfoData(InterfaceVO interfaceVO) {
		String typeCode = interfaceVO.getTypeCode();
		if(StringUtil.isEmpty(typeCode)){
			return R.failed("接口类型不能为空");
		}else {
			List<SjdzInterfaceInfo> sjdzInterfaceInfos = baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery().eq(SjdzInterfaceInfo::getTypeCode, typeCode));
			if (sjdzInterfaceInfos.size() == 0) {
				return R.failed("未查询到该类型接口信息");
			}
			SjdzInterfaceInfo sjdzInterfaceInfo = sjdzInterfaceInfos.get(0);
			String authUserKey = sjdzInterfaceInfo.getAuthUserKey();
			String id = interfaceVO.getId();
			String interfaceAddress = sjdzInterfaceInfo.getInterfaceAddress();
			String url= interfaceAddress;
			if(StringUtil.isNotEmpty(id)){
				url=url+"/"+id;
			}
			Map<String, Object> params = interfaceVO.getParams();
			if(params!=null){
				String s = UrlUtils.mapToUrlParams(params);
				url+="?"+s;
			}
			log.info("url:{}",url);
			String method = sjdzInterfaceInfo.getMethod();
			HttpRequest request = HttpUtil.createRequest(cn.hutool.http.Method.valueOf(method), url);
			if(StringUtil.isNotEmpty(authUserKey)){
				request.header("Authorization",authUserKey);
			}
			request.header("Content-Type","application/json");
			Map<String, Object> data = interfaceVO.getData();
			if(data!=null){
				String s = JsonUtils.toJson(data);
				request.body(s);
			}
			String result  = request.execute().body();
			log.info("result:{}",result);
			ObjectMapper objectMapper = new ObjectMapper();
			try {
				JsonNode jsonNode = objectMapper.readTree(result);
				return jsonNode;
			} catch (JsonProcessingException e) {
				e.printStackTrace();
			}
			return R.ok();
		}
	}

	@Override
	public Object getWgjzInfoData(InterfaceVO interfaceVO) {
		String typeCode = interfaceVO.getTypeCode();
		if(StringUtil.isEmpty(typeCode)){
			return R.failed("接口类型不能为空");
		}else {
			List<SjdzInterfaceInfo> sjdzInterfaceInfos = baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery().eq(SjdzInterfaceInfo::getTypeCode, typeCode));
			if (sjdzInterfaceInfos.size() == 0) {
				return R.failed("未查询到该类型接口信息");
			}
			SjdzInterfaceInfo sjdzInterfaceInfo = sjdzInterfaceInfos.get(0);
			String authUserKey = sjdzInterfaceInfo.getAuthUserKey();
			String id = interfaceVO.getId();
			String interfaceAddress = sjdzInterfaceInfo.getInterfaceAddress();
			String url= interfaceAddress;
			if(StringUtil.isNotEmpty(id)){
				url=url+"/"+id;
			}
			Map<String, Object> params = interfaceVO.getParams();
			if(params!=null){
				String s = UrlUtils.mapToUrlParams(params);
				url+="?"+s;
			}
			log.info("url:{}",url);
			String method = sjdzInterfaceInfo.getMethod();
			HttpRequest request = HttpUtil.createRequest(cn.hutool.http.Method.valueOf(method), url);
			if(StringUtil.isNotEmpty(authUserKey)){
				request.header("token",authUserKey);
			}
			request.header("Content-Type","application/json");
			Map<String, Object> data = interfaceVO.getData();
			if(data!=null){
				String s = JsonUtils.toJson(data);
				request.body(s);
			}
			String result  = request.execute().body();
			log.info("result:{}",result);
			ObjectMapper objectMapper = new ObjectMapper();
			try {
				JsonNode jsonNode = objectMapper.readTree(result);
				return jsonNode;
			} catch (JsonProcessingException e) {
				e.printStackTrace();
			}
			return R.ok();
		}
	}

	@Override
	public R clearRedisData(InterfaceVO interfaceVO) {
		int i = interfaceVO.hashCode();
		String typeCode = interfaceVO.getTypeCode();
		//需要缓存
		Object o = RedisUtils.get("sjdz_" + typeCode + ":" + i);
		if (o != null) {
			RedisUtils.del("sjdz_" + typeCode + ":" + i);
		}
		return R.ok();
	}
}