package com.hncy.sjdz.base.util.cdEncryption;

import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Date;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * DataEncryptionUtil
 *
 * @author fate
 * @version 0.0.1
 * @since 2024-11-20 10:40
 **/
@Log4j2
@Component
@ConditionalOnBean(CdEncryptionUtil.class)
public class DataEncryptionUtil {
    @Resource
    private CdEncryptionUtil cdEncryptionUtil;
    private final Map<String, Object> tokenInfo = new ConcurrentHashMap<>();

    private String getToken() {
        Date fetchTime = (Date) tokenInfo.getOrDefault("fetchTime", null);
        if (fetchTime == null) {
            String token = cdEncryptionUtil.getToken();
            tokenInfo.put("fetchToken", StringUtils.defaultIfEmpty(token, null));
            tokenInfo.put("fetchTime", new Date());
        } else {
            // 当前时间与上次取token时间相比，相差大于30秒，则需要重新取token
            if (new Date().getTime() - fetchTime.getTime() >= 30 * 1000L) {
                String token = cdEncryptionUtil.getToken();
                tokenInfo.put("fetchToken", StringUtils.defaultIfEmpty(token, null));
                tokenInfo.put("fetchTime", new Date());
            }
        }
        String fetchToken = (String) tokenInfo.getOrDefault("fetchToken", null);
        if (fetchToken == null) {
            throw new NullPointerException("加密时获取token失败");
        }
        return fetchToken;
    }

    public String encryptSM4(String data) {
        if (StringUtils.isEmpty(data)) {
            return data;
        }
        return cdEncryptionUtil.encryptSM4(getToken(), data);
    }

    public String decryptSM4(String data) {
        if (StringUtils.isEmpty(data)) {
            return data;
        }
        return cdEncryptionUtil.decryptSM4(getToken(), data);
    }

    public String hmac(String data) {
        if (StringUtils.isEmpty(data)) {
            return data;
        }
        return cdEncryptionUtil.hmac(getToken(), data);
    }

    public String hmac(String token, String data) {
        if (StringUtils.isEmpty(data)) {
            return data;
        }
        return cdEncryptionUtil.hmac(token, data);
    }

    public boolean enable() {
        return cdEncryptionUtil.enable();
    }

    @PostConstruct
    public void init() {
        log.info("已启用重要数据加密");
    }
}
